import Col from "antd/es/col";
import { Row } from "antd/lib/grid";
import * as echarts from "echarts";

import "./kanban.less";
import { useEffect } from "react";

const KanBan = () => {
  const initChart = () => {
    var myChart = echarts.init(document.getElementById("yibiaopan"));
    var option = {
      series: [
        {
          type: "gauge",
          center: ["40%", "70%"],
          startAngle: 200,
          endAngle: -20,
          min: 0,
          max: 30,
          splitNumber: 12,
          itemStyle: {
            color: "#FFAB91",
          },
          progress: {
            show: true,
            width: 20,
          },
          pointer: {
            show: false,
          },
          axisLine: {
            lineStyle: {
              width: 15,
            },
          },
          axisTick: {
            distance: -45,
            splitNumber: 5,
            lineStyle: {
              width: 2,
              color: "#999",
            },
          },
          splitLine: {
            distance: -42,
            length: 14,
            lineStyle: {
              width: 3,
              color: "#999",
            },
          },
          axisLabel: {
            distance: -20,
            color: "#999",
            fontSize: 20,
          },
          anchor: {
            show: false,
          },
          title: {
            show: false,
          },
          detail: {
            valueAnimation: true,
            width: "40%",
            lineHeight: 40,
            borderRadius: 8,
            offsetCenter: [0, "-10%"],
            fontSize: 20,
            fontWeight: "bolder",
            formatter: "{value} °C",
            color: "inherit",
          },
          data: [
            {
              value: 20,
            },
          ],
        },
        {
          type: "gauge",
          center: ["40%", "70%"],
          startAngle: 200,
          endAngle: -20,
          min: 0,
          max: 60,
          itemStyle: {
            color: "#FD7347",
          },
          progress: {
            show: true,
            width: 8,
          },
          pointer: {
            show: false,
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
          splitLine: {
            show: false,
          },
          axisLabel: {
            show: false,
          },
          detail: {
            show: false,
          },
          data: [
            {
              value: 20,
            },
          ],
        },
      ],
    };
    option && myChart.setOption(option);
  };
  const sourece = (id: string) => {
    var myChart = echarts.init(document.getElementById(id));
    var option = {
      legend: {
        top: "bottom",
        show: false,
      },
      series: [
        {
          type: "pie",
          radius: [40, 80],
          center: ["50%", "50%"],
          itemStyle: {
            borderRadius: 2,
          },
          data: [
            { value: 40, name: "第三方" },
            { value: 18, name: "购买" },
            { value: 18, name: "自有" },
          ],
        },
      ],
    };
    option && myChart.setOption(option);
  };
  const gailan = () => {
    var myChart = echarts.init(document.getElementById("gailan"));
    var option = {
      xAxis: {
        type: "category",
        data: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
        axisLabel: {
          show: true,
          interval: 0,
          rotate: 30,
        },
      },
      grid: { top: "10%", bottom: "15%", right: "5%" },
      yAxis: {
        type: "value",
        splitLine: {
          show: false, // 去除网格线
        },
      },
      series: [
        {
          data: [820, 932, 901, 934, 1290, 1330, 1320],
          type: "line",
          smooth: true,
          areaStyle: {
            opacity: 0.1,
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              {
                offset: 0,
                color: "rgb(128, 255, 165)",
              },
              {
                offset: 1,
                color: "rgb(1, 191, 236)",
              },
            ]),
          },
        },
      ],
    };
    option && myChart.setOption(option);
  };
  useEffect(() => {
    initChart();
    sourece("sourece");
    sourece("yujing");
    sourece("baozhiqi");
    sourece("level");
    gailan();
  }, []);
  return (
    <>
      <Row style={{ margin: "10px" }}>
        <Col className="gutter-row" span={6}>
          <div
            className="kanban-item"
            style={{ backgroundColor: "rgba(37, 52, 70, 0.4)" }}
          >
            <div>
              <p
                style={{
                  backgroundColor: "#29ecb4",
                  width: "100%",
                  padding: "10px",
                }}
              >
                安全运行天数
              </p>
              <p
                style={{
                  fontSize: "30px",
                  margin: "0px",
                  fontWeight: "800",
                  color: "#29ecb4",
                }}
              >
                109
              </p>
              <p style={{ color: "#29ecb4" }}>2024 / 12 / 12 星期四 09:10</p>
            </div>
          </div>
          <div className="kanban-item" style={{ margin: "10px 0px" }}>
            <div>
              <div
                id="yibiaopan"
                style={{ width: "240px", height: "240px" }}
              ></div>
            </div>
          </div>
          <div className="kanban-item">
            <div>
              <div
                id="sourece"
                style={{ width: "240px", height: "240px" }}
              ></div>
            </div>
          </div>
        </Col>

        <Col className="gutter-row" span={12}>
          <div className="kanban-item">
            <div>暂无视频</div>
          </div>
          <div className="kanban-item" style={{ margin: "10px 0px" }}>
            <div>暂无视频</div>
          </div>
          <div className="kanban-item">
            <div id="gailan" style={{ width: "100%", height: "240px" }}></div>
          </div>
        </Col>
        <Col className="gutter-row" span={6}>
          <div className="kanban-item">
            <div id="yujing" style={{ width: "240px", height: "240px" }}></div>
          </div>
          <div className="kanban-item" style={{ margin: "10px 0px" }}>
            <div
              id="baozhiqi"
              style={{ width: "240px", height: "240px" }}
            ></div>
          </div>
          <div className="kanban-item">
            <div id="level" style={{ width: "240px", height: "240px" }}></div>
          </div>
        </Col>
      </Row>
    </>
  );
};

export default KanBan;
